@@ -1,5 +1,6 @@
 from .. import mongo
 
+from .base_document import BaseDocument
 
 class RecipeIngredient(mongo.EmbeddedDocument):
     quantity = mongo.FloatField()
@@ -9,7 +10,7 @@ class RecipeIngredient(mongo.EmbeddedDocument):
     ingredient = mongo.ReferenceField('Ingredient', required=True)
 
 
-class Recipe(mongo.Document):
+class Recipe(BaseDocument):
     name = mongo.StringField(required=True)
     description = mongo.StringField()
     preparation = mongo.StringField() #TODO will be a list of strings
@@ -30,11 +31,8 @@ class Recipe(mongo.Document):
         mongo.StringField(), default=None
     )
 
-    owner = mongo.ReferenceField('User', required=True)
-
     meta = {
-        'collection': 'recipes',
-        'strict' : False #TODO remove when use base_model as parent model
+        'collection': 'recipes'
     }
 
     def __repr__(self):
